@@ -5,7 +5,7 @@
 # Author    : Chris Jones
 # Email     : crj341@student.bham.ac.uk
 # Date      : 26/06/2020
-# Version   : 0.1.21
+# Version   : 0.1.22
 
 import  numpy                   as      np
 import  plotly.graph_objects    as      go
@@ -551,8 +551,8 @@ class AFM:
             _approach = self.approach[:,i]
             _retract = self.retract[:,i]
                 
-            tip_approach = _z[:self.samps_line] + self.spr_const * _approach
-            tip_retract = _z[self.samps_line:] + self.spr_const * _retract
+            tip_approach = _z[:self.samps_line] - self.spr_const * _approach
+            tip_retract = _z[self.samps_line:] - self.spr_const * _retract
 
             tip_position = np.concatenate((tip_approach, tip_retract), axis = 0)
 
